@@ -1,4 +1,4 @@
-from ._common import *
+from _common import *
 
 IEX_DATA_POINT_URL = 'https://cloud.iexapis.com/stable/data-points/'
 IEX_TIME_SERIES_URL = 'https://cloud.iexapis.com/stable/time-series/'
@@ -17,27 +17,31 @@ def economic_data(symbol, vprint=False):
     return get_iex_json_request(url, vprint=vprint)
 economic_data.__doc__='Returns economic data for the requested economic indicator symbol.'
 
-IEX_DATA_POINT_URL = 'https://cloud.iexapis.com/stable/data-points/'
-def generic_data_point(symbol, key=None, vprint=False):
-    ## Generic endpoint used to access all 'Data Point' data sets on IEX
-    url = IEX_DATA_POINT_URL + f'{symbol}'
-    if key:
-        url += f'/{key}?'
-    else:
-        url+= '?'
+def generic_data_point(symbol, key, vprint=False, **queries):
+    """Credit usage depends on what is requested.
+    This is a generic endpoint for any and all data points available on IEX Cloud.
+    Parameters:
+    symbol -> the symbol for the datapoint you wish to retrieve
+    key -> the classification for the datapoint you wish to retrieve
+    **queries -> enter any key/value pairs into the arguments and they will be transferred to the request
+    """
+    url = IEX_DATA_POINT_URL + f'{key}/{symbol}?'
+    for key, value in queries.items():
+        url += (f"&{key}={value}")
     return get_iex_json_request(url, vprint=vprint)
-generic_data_point.__doc__='Generic endpoint used to access all \'Data Point\' data sets on IEX.'
 
-
-IEX_TIME_SERIES_URL = 'https://cloud.iexapis.com/stable/time-series/'
-def generic_time_series(symbol, *args, vprint=False):
-    ## Generic endpoint used to access all 'Time Series' data sets on IEX
-    url = IEX_TIME_SERIES_URL + f'{symbol}'
-    for a in args:
-        url += f'/{a}'
-    url += '?'
+def generic_time_series(symbol, key, vprint=False, **queries):
+    """Credit usage depends on what is requested.
+    This is a generic endpoint for any and all time series data available on IEX Cloud.
+    Parameters:
+    symbol -> the symbol for the time series you wish to retrieve
+    key -> the classification for the time series you wish to retrieve
+    **queries -> enter any key/value pairs into the arguments and they will be transferred to the request
+    """
+    url = IEX_TIME_SERIES_URL + f'{key}/{symbol}?'
+    for key, value in queries.items():
+        url += (f"&{key}={value}")
     return get_iex_json_request(url, vprint=vprint)
-generic_time_series.__doc__='Generic endpoint used to access all \'Time Series\' data sets on IEX'
 
 #   Collections
 IEX_COLLECTION_URL = prepend_iex_url('stock') + 'market/collection/{collectionType}?collectionName={collectionName}'
